diff --git a/examples/select2/index.html b/examples/select2/index.html
index 45e933f9..77883bf9 100644
--- a/examples/select2/index.html
+++ b/examples/select2/index.html
@@ -40,7 +40,7 @@
Vue.component('select2', {
props: ['options', 'value'],
template: '#select2-template',
- ready: function () {
+ mounted: function () {
var vm = this
$(this.$el)
.val(this.value)
diff --git a/src/core/config.js b/src/core/config.js
index ba01ddb3..22e7df48 100644
--- a/src/core/config.js
+++ b/src/core/config.js
@@ -46,7 +46,6 @@ export default {
'created',
'beforeMount',
'mounted',
- 'ready',
'beforeUpdate',
'updated',
'beforeDestroy',
diff --git a/src/core/vdom/create-component.js b/src/core/vdom/create-component.js
index 140981c7..a24d512e 100644
--- a/src/core/vdom/create-component.js
+++ b/src/core/vdom/create-component.js
@@ -105,7 +105,7 @@ function prepatch (oldVnode, vnode) {
}
function insert (vnode) {
- callHook(vnode.child, 'ready')
+ callHook(vnode.child, 'mounted')
}
function destroy (vnode) {
diff --git a/src/core/instance/lifecycle.js b/src/core/instance/lifecycle.js
index 7863a62f..0e0e5a6a 100644
--- a/src/core/instance/lifecycle.js
+++ b/src/core/instance/lifecycle.js
@@ -40,12 +40,13 @@ export function lifecycleMixin (Vue) {
}
}
}
+ callHook(this, 'beforeMount')
this._watcher = new Watcher(this, this._render, this._update)
this._update(this._watcher.value)
this._mounted = true
// root instance, call ready on self
if (this.$root === this) {
- callHook(this, 'ready')
+ callHook(this, 'mounted')
}
return this
}
@@ -40,12 +40,13 @@ export function lifecycleMixin (Vue) {
this._update(this._watcher.value)
this._mounted = true
- // root instance, call ready on self
+ // root instance, call mounted on self
if (this.$root === this) {